package models

// 表
type Activity struct {
	Id       int    `gorm:"PRIMARY_KEY;AUTO_INCREMENT"` // 活动 ID
	Title    string // 活动标题
	Subtitle string // 活动副标题
	CityId   int    `gorm:"column:city_id"` // 活动地点 ID
	Address  string // 活动详细地址
	Lng      string `gorm:"column:longitude"` // 活动位置的经度
	Lat      string `gorm:"column:latitude"`  // 活动位置的纬度
	// SignUpStart int64  `gorm:"column:sign_up_start"` // 报名开始时间戳
	SignUpDeadline int64  `gorm:"column:sign_up_deadline"` // 报名截止时间戳
	SignUpNotice   string `gorm:"column:sign_up_notice"`   // 报名须知
	StartTime      int64  `gorm:"column:start_time"`       // 活动开始时间戳
	// EndTime          int64  `gorm:"column:end_time"`            // 活动结束时间戳
	PosterPhoto      string `gorm:"column:poster_photo"`        // 活动海报
	PosterPhotoThumb string `gorm:"column:poster_photo_thumb"`  // 活动海报缩略图
	LimitNum         int    `gorm:"column:limit_num;default:0"` // 限制报名人数，0表示无限制
	JoinNum          int    `gorm:"column:join_num"`            // 已报名人数
	PhoneNumber      string `gorm:"column:phone_number"`        // 联系方式
	Type             int8   // 活动形式
	// Content		string	// 活动内容
	IsInsurance int8   `gorm:"column:is_insurance;default:0"` // 是否提供保险:报名不需要保险0:否;报名需要保险1:是;2不需要报名
	Status      int    // 活动状态 1:已发布 2:待审核 3:未通过 4:草稿 9:已删除
	Reason      string // 审核原因
	IsRecommend int8   `gorm:"column:is_recommend;default:0"` // 0:未推荐;1:已推荐
	CreateTime  int64  `gorm:"column:ctime"`                  // 创建时间
	ModifyTime  int64  `gorm:"column:mtime"`                  // 修改时间
	UserOrgId   int    `gorm:"column:user_org_id"`            // 所属发布机构 ID
	UserAppId   int    `gorm:"column:user_app_id"`            // 所属发布应用 ID
	CommentNum  int    `gorm:"column:comment_num;default:0"`  // 评论数
	StarNum     int    `gorm:"column:star_num;default:0"`     // 点赞书
	ReadNum     int    `gorm:"column:read_num;default:0"`     // 阅读数
}

func (Activity) TableName() string {
	return "sgj_patient_activity"
}

type ActivityParagraph struct {
	Id         int `gorm:"PRIMARY_KEY;AUTO_INCREMENT"` // 记录 ID
	ActivityId int `gorm:"column:activity_id"`         // 活动 ID
	Title      string
	Text       string
	Image      string
	Status     int8  // 状态 0.无效 1.有效
	CreateTime int64 `gorm:"column:ctime"` // 创建时间
	ModifyTime int64 `gorm:"column:mtime"` // 修改时间
}

func (ActivityParagraph) TableName() string {
	return "sgj_patient_activity_paragraph"
}

type ActivityUser struct {
	Id          int    `gorm:"PRIMARY_KEY;AUTO_INCREMENT"` // 记录 ID
	ActivityId  int    `gorm:"column:activity_id"`         // 活动 ID
	UserId      int    `gorm:"column:user_id"`             // 参与者 ID
	IDCardNo    string `gorm:"column:idcard_no"`           // 身份证号
	Mobile      string
	Realname    string
	Avatar      string
	AvatarThumb string
	Status      int8  // 状态 0.无效 1.有效
	CreateTime  int64 `gorm:"column:ctime"` // 报名时间
	ModifyTime  int64 `gorm:"column:mtime"` // 修改时间
}

func (ActivityUser) TableName() string {
	return "sgj_patient_activity_user"
}

type ActivityWxShare struct {
	Id         int `gorm:"PRIMARY_KEY;AUTO_INCREMENT"` // 记录 ID
	ActivityId int `gorm:"column:activity_id"`         // 活动 ID
	Title      string
	Subtitle   string
	Image      string
	Status     int8   // 状态 0.无效 1.有效
	CreateTime int64  `gorm:"column:ctime"`     // 创建时间
	ModifyTime int64  `gorm:"column:mtime"`     // 修改时间
	ShortURL   string `gorm:"column:short_url"` // 短链接
}

func (ActivityWxShare) TableName() string {
	return "sgj_patient_activity_wx_share"
}
